export interface paths {
    "/auth/login": {
        parameters: {
            query?: never;
            header?: never;
            path?: never;
            cookie?: never;
        };
        get?: never;
        put?: never;
        post: operations["AuthController_loginUser"];
        delete?: never;
        options?: never;
        head?: never;
        patch?: never;
        trace?: never;
    };
    "/auth/refresh": {
        parameters: {
            query?: never;
            header?: never;
            path?: never;
            cookie?: never;
        };
        get?: never;
        put?: never;
        post: operations["AuthController_refreshToken"];
        delete?: never;
        options?: never;
        head?: never;
        patch?: never;
        trace?: never;
    };
    "/account/create": {
        parameters: {
            query?: never;
            header?: never;
            path?: never;
            cookie?: never;
        };
        get?: never;
        put?: never;
        post: operations["AccountController_createCuenta"];
        delete?: never;
        options?: never;
        head?: never;
        patch?: never;
        trace?: never;
    };
    "/account/global-filter": {
        parameters: {
            query?: never;
            header?: never;
            path?: never;
            cookie?: never;
        };
        get: operations["AccountController_getFiltroBase"];
        put?: never;
        post?: never;
        delete?: never;
        options?: never;
        head?: never;
        patch: operations["AccountController_updateFiltroBase"];
        trace?: never;
    };
    "/account/me": {
        parameters: {
            query?: never;
            header?: never;
            path?: never;
            cookie?: never;
        };
        get: operations["AccountController_getMe"];
        put?: never;
        post?: never;
        delete?: never;
        options?: never;
        head?: never;
        patch?: never;
        trace?: never;
    };
}
export type webhooks = Record<string, never>;
export interface components {
    schemas: {
        LoginDto: {
            username: string;
            password: string;
        };
        LoginResponseDto: {
            user: {
                id?: string;
                username?: string;
                role?: "USER" | "ADMIN";
                created_at?: string;
                updated_at?: string;
                globalFilter?: {
                    tags: {
                        id: string;
                        name: string;
                        group: {
                            id: string;
                            color: string;
                            isExclusive: boolean;
                        };
                    };
                    active: boolean;
                };
                isGlobalFilterActive: boolean;
                fcmToken: string[];
            };
            backendTokens: {
                accessToken?: string;
                refreshToken?: string;
            };
        };
        CreateAccountDto: {
            username: string;
            password: string;
            role: "USER" | "ADMIN";
        };
        CreateCuentaResponseDto: {
            id: string;
            username: string;
            role: "USER" | "ADMIN";
            isGlobalFilterActive: boolean;
            fcmToken: string[];
        };
        UpdateGlobalFilterDto: {
            active: boolean;
            tagsIds: string[];
        };
        UpdateGlobalFilterResponseDto: {
            id: string;
            nombreUsuario: string;
            esAdmin: boolean;
            fcmToken: string | null;
            filtroBaseActivo: boolean;
            filtroBase: {
                active?: boolean;
                etiquetas?: {
                    id: string;
                    name: string;
                    groupId: string;
                    type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
                    created_at: string;
                    updated_at: string;
                }[];
            };
        };
        GetGlobalFilterResponseDto: {
            active: boolean;
            globalFilter: {
                id: string;
                name: string;
                type: "PROFILE" | "EVENT" | "PARTICIPANT" | "NOT_IN_SYSTEM";
                group: {
                    id: string;
                    color: string;
                    isExclusive: boolean;
                };
            }[];
        };
        GetMeResponseDto: {
            id: string;
            username: string;
            role: "USER" | "ADMIN";
            created_at: string;
            updated_at: string;
            globalFilter: {
                tags?: {
                    id: string;
                    name: string;
                    group: {
                        id: string;
                        color: string;
                        isExclusive: boolean;
                    };
                };
                active?: boolean;
            };
            isGlobalFilterActive: boolean;
            fcmToken: string[];
        };
    };
    responses: never;
    parameters: never;
    requestBodies: never;
    headers: never;
    pathItems: never;
}
export type $defs = Record<string, never>;
export interface operations {
    AuthController_loginUser: {
        parameters: {
            query?: never;
            header?: never;
            path?: never;
            cookie?: never;
        };
        requestBody: {
            content: {
                "application/json": components["schemas"]["LoginDto"];
            };
        };
        responses: {
            200: {
                headers: {
                    [name: string]: unknown;
                };
                content: {
                    "application/json": components["schemas"]["LoginResponseDto"];
                };
            };
        };
    };
    AuthController_refreshToken: {
        parameters: {
            query?: never;
            header?: never;
            path?: never;
            cookie?: never;
        };
        requestBody?: never;
        responses: {
            201: {
                headers: {
                    [name: string]: unknown;
                };
                content?: never;
            };
        };
    };
    AccountController_createCuenta: {
        parameters: {
            query?: never;
            header?: never;
            path?: never;
            cookie?: never;
        };
        requestBody: {
            content: {
                "application/json": components["schemas"]["CreateAccountDto"];
            };
        };
        responses: {
            201: {
                headers: {
                    [name: string]: unknown;
                };
                content: {
                    "application/json": components["schemas"]["CreateCuentaResponseDto"];
                };
            };
        };
    };
    AccountController_getFiltroBase: {
        parameters: {
            query?: never;
            header?: never;
            path?: never;
            cookie?: never;
        };
        requestBody?: never;
        responses: {
            200: {
                headers: {
                    [name: string]: unknown;
                };
                content: {
                    "application/json": components["schemas"]["GetGlobalFilterResponseDto"];
                };
            };
        };
    };
    AccountController_updateFiltroBase: {
        parameters: {
            query?: never;
            header?: never;
            path?: never;
            cookie?: never;
        };
        requestBody: {
            content: {
                "application/json": components["schemas"]["UpdateGlobalFilterDto"];
            };
        };
        responses: {
            200: {
                headers: {
                    [name: string]: unknown;
                };
                content: {
                    "application/json": components["schemas"]["UpdateGlobalFilterResponseDto"];
                };
            };
        };
    };
    AccountController_getMe: {
        parameters: {
            query?: never;
            header?: never;
            path?: never;
            cookie?: never;
        };
        requestBody?: never;
        responses: {
            200: {
                headers: {
                    [name: string]: unknown;
                };
                content: {
                    "application/json": components["schemas"]["GetMeResponseDto"];
                };
            };
        };
    };
}
